@@ -10,6 +10,7 @@ sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "../"
 import aiohttp  # noqa: E402
 
 import tibber  # noqa: E402
+from tibber.exceptions import FatalHttpException, InvalidLogin
 
 
 @pytest.mark.asyncio
@@ -59,7 +60,7 @@ async def test_tibber():
                     assert isinstance(home.price_total[key], (float, int))
             else:
                 k += 1
-                assert home.home_id == "cc83e83e-8cbf-4595-9bf7-c3cf192f7d9c"
+                assert home.home_id == "96a14971-525a-4420-aae9-e5aedaa129ff"
                 assert home.address1 == "Winterfell Castle 1"
                 assert home.country is None
 
@@ -76,10 +77,24 @@ async def test_tibber_invalid_token():
             access_token="INVALID_TOKEN", websession=session
         )
         with pytest.raises(
-            tibber.InvalidLogin, match="No valid access token in request"
+            InvalidLogin, match="Context creation failed: invalid token"
         ):
             await tibber_connection.update_info()
-        assert tibber_connection.name is None
+        assert not tibber_connection.name
+        assert tibber_connection.get_homes() == []
+
+
+@pytest.mark.asyncio
+async def test_tibber_invalid_query():
+    async with aiohttp.ClientSession() as session:
+        tibber_connection = tibber.Tibber(websession=session)
+
+        with pytest.raises(
+            FatalHttpException, match="Syntax Error*"
+        ):
+            await tibber_connection.execute("invalidquery")
+
+        assert not tibber_connection.name
         assert tibber_connection.get_homes() == []
 
 
