@@ -4,7 +4,8 @@ from __future__ import annotations
 import asyncio
 import datetime as dt
 import logging
-from typing import TYPE_CHECKING, Callable
+from collections.abc import Callable
+from typing import TYPE_CHECKING
 
 from dateutil.parser import parse
 from gql import gql
@@ -65,9 +66,6 @@ class TibberHome:
         self._hourly_consumption_data: HourlyData = HourlyData()
         self._hourly_production_data: HourlyData = HourlyData(production=True)
         self._last_rt_data_received: dt.datetime = dt.datetime.now()
-        self._rt_listener: None | asyncio.Task = None
-        self._rt_callback: Callable | None = None
-        self._rt_stopped: bool = True
 
     async def _fetch_data(self, hourly_data: HourlyData) -> None:
         """Update hourly consumption or production data asynchronously."""
@@ -413,12 +411,6 @@ class TibberHome:
         async def _start():
             """Subscribe to Tibber."""
             while True:
-                while not self._tibber_control.rt_subscription_running:
-                    _LOGGER.debug("Waiting for rt_connect")
-                    await asyncio.sleep(1)
-                if self._rt_stopped:
-                    _LOGGER.debug("Stopping rt_subscribe")
-                    return
                 try:
                     async for data in self._tibber_control.sub_manager.session.subscribe(
                         gql(LIVE_SUBSCRIBE % self.home_id)
@@ -431,39 +423,16 @@ class TibberHome:
                         callback(data)
                         self._last_rt_data_received = dt.datetime.now()
                         _LOGGER.debug(
-                            "Data received for %s: %s",
+                            "Data received for %s",
                             self.home_id,
-                            data,
                         )
-                        if self._rt_stopped:
-                            _LOGGER.debug("Stopping rt_subscribe loop")
-                            return
                 except Exception:  # pylint: disable=broad-except
-                    _LOGGER.exception("Error in rt_subscribe")
+                    if self.rt_subscription_running:
+                        _LOGGER.exception("Error in rt_subscribe")
                     await asyncio.sleep(10)
 
-        self._rt_callback = callback
-        self._rt_listener = asyncio.create_task(_start())
-        self._rt_stopped = False
         await self._tibber_control.rt_connect()
-
-    async def rt_resubscribe(self) -> None:
-        """Resubscribe to Tibber data."""
-        _LOGGER.debug("Resubscribe, %s", self.home_id)
-        self.rt_unsubscribe()
-        if self._rt_callback is None:
-            _LOGGER.warning("No callback set for rt_resubscribe")
-            return
-        await self.rt_subscribe(self._rt_callback)
-
-    def rt_unsubscribe(self) -> None:
-        """Unsubscribe to Tibber data."""
-        _LOGGER.debug("Unsubscribe, %s", self.home_id)
-        self._rt_stopped = True
-        if self._rt_listener is None:
-            return
-        self._rt_listener.cancel()
-        self._rt_listener = None
+        asyncio.create_task(_start())
 
     @property
     def rt_subscription_running(self) -> bool:
@@ -496,7 +465,7 @@ class TibberHome:
                 cons_or_prod_str,
                 resolution,
                 _n_data,
-                "profit" if production else "totalCost cost",
+                "profit" if production else "cost",
                 cursor,
             )
             if not (data := await self._tibber_control.execute(query, timeout=30)):
@@ -505,6 +474,11 @@ class TibberHome:
             data = data["viewer"]["home"][cons_or_prod_str]
             if data is None:
                 continue
+            if not production:
+                for node in data["nodes"]:
+                    if "cost" in node:
+                        node["totalCost"] = node["cost"]
+
             res.extend(data["nodes"])
             n_data -= len(data["nodes"])
             if (
@@ -586,15 +560,8 @@ class TibberHome:
                 or ""
             ).lower()
         ):
-            if now.month < 7:
-                grid_price = 47.39 / 100
-            else:
-                grid_price = 47.25 / 100
-            if now.hour >= 22 or now.hour < 6:
-                grid_price -= 12 / 100
-            attr["grid_price"] = round(grid_price, 3)
             _LOGGER.warning(
-                "Grid price attribute is deprecated and will be removed. "
+                "Grid price attribute is deprecated and removed. "
                 "Use https://github.com/Danielhiversen/home_assistant_glitre"
             )
         return attr
